from itertools import combinations
from math import prod

def is_prime(num):
    if num < 2:
        return False
    for i in range(2, int(num**0.5) + 1):
        if num % i == 0:
            return False
    return True

def generate_primes(n):
    primes = []
    candidate = 2
    while len(primes) < n:
        if is_prime(candidate):
            primes.append(candidate)
        candidate += 1
    return primes

def find_beautiful_partition(primes):
    total_product = prod(primes)
    n = len(primes)
    best_a = None
    best_b = None
    min_diff = float('inf')

    # Check all possible subsets (1 to n-1 items)
    for r in range(1, n):  # r is the size of subset A
        for subset in combinations(primes, r):
            a = prod(subset)
            b = total_product // a
            
            if a < b:
                diff = b - a
                if diff < min_diff:
                    min_diff = diff
                    best_a = a
                    best_b = b

    return best_a

n = int(input().strip())
primes = generate_primes(n)
result = find_beautiful_partition(primes)
print(result)
