#include <iostream>
#include <vector>
#include <unordered_map>
#include <algorithm>

using namespace std;

vector<int> generate_primes(int n) {
    vector<int> primes;
    int candidate = 2;
    while (primes.size() < n) {
        bool is_prime = true;
        for (int p : primes) {
            if (p * p > candidate) {
                break;
            }
            if (candidate % p == 0) {
                is_prime = false;
                break;
            }
        }
        if (is_prime) {
            primes.push_back(candidate);
        }
        candidate++;
    }
    return primes;
}

int beautiful_partition(int n) {
    vector<int> primes = generate_primes(n);
    long long total_product = 1;
    for (int prime : primes) {
        total_product *= prime;
    }

    unordered_map<long long, long long> dp;
    dp[1] = 0;

    for (int prime : primes) {
        unordered_map<long long, long long> new_dp = dp;
        for (const auto& [product, sum] : dp) {
            long long new_product = product * prime;
            if (new_dp.find(new_product) == new_dp.end()) {
                new_dp[new_product] = sum + prime;
            } else {
                new_dp[new_product] = min(new_dp[new_product], sum + prime);
            }
        }
        dp = new_dp;
    }

    long long min_diff = LLONG_MAX;
    long long best_a = 1;

    for (const auto& [a, _] : dp) {
        long long b = total_product / a;
        if (a < b) {
            long long diff = b - a;
            if (diff < min_diff) {
                min_diff = diff;
                best_a = a;
            }
        }
    }

    return best_a;
}

int main() {
    int n;
    cin >> n;
    int result = beautiful_partition(n);
    cout << result << endl;
    return 0;
}
