import math
import bisect
from itertools import combinations

def get_primes(n):
    primes = []
    x = 2
    while len(primes) < n:
        is_prime = True
        for p in primes:
            if p * p > x:
                break
            if x % p == 0:
                is_prime = False
                break
        if is_prime:
            primes.append(x)
        x += 1
    return primes

def find_best_a(primes):
    n = len(primes)
    P = 1
    log_P = 0.0
    for p in primes:
        P *= p
        log_P += math.log(p)
    target = log_P / 2

    m = n // 2
    left = primes[:m]
    right = primes[m:]

    def get_subsets(lst):
        subsets = []
        for i in range(len(lst) + 1):
            for comb in combinations(lst, i):
                sum_log = 0.0
                product = 1
                for p in comb:
                    sum_log += math.log(p)
                    product *= p
                subsets.append((sum_log, product))
        return subsets

    left_subsets = get_subsets(left)
    right_subsets = get_subsets(right)
    right_subsets.sort()
    right_logs = [x[0] for x in right_subsets]

    best_a = 1
    min_diff = P - 1
    for sum_l, prod_l in left_subsets:
        remaining = target - sum_l
        if remaining < 0:
            continue
        idx = bisect.bisect_right(right_logs, remaining) - 1
        if idx >= 0:
            sum_r, prod_r = right_subsets[idx]
            a = prod_l * prod_r
            b = P // a
            if a < b:
                diff = b - a
                if diff < min_diff:
                    min_diff = diff
                    best_a = a
    return best_a

n = int(input())
primes = get_primes(n)
print(find_best_a(primes))