#include <iostream>
#include <vector>
#include <cmath>
#include <climits>

using namespace std;

bool is_prime(int num) {
    if (num < 2) {
        return false;
    }
    for (int i = 2; i <= sqrt(num); ++i) {
        if (num % i == 0) {
            return false;
        }
    }
    return true;
}

vector<int> generate_primes(int n) {
    vector<int> primes;
    int candidate = 2;
    while (primes.size() < n) {
        if (is_prime(candidate)) {
            primes.push_back(candidate);
        }
        candidate++;
    }
    return primes;
}

int beautiful_partition(int n) {
    vector<int> primes = generate_primes(n);
    int total_primes = primes.size();

    int best_a = -1;
    int best_diff = INT_MAX;

    for (int mask = 1; mask < (1 << total_primes); ++mask) {
        long long a_product = 1;
        long long b_product = 1;
        int a_count = 0;
        int b_count = 0;

        for (int i = 0; i < total_primes; ++i) {
            if (mask & (1 << i)) {
                a_product *= primes[i];
                a_count++;
            } else {
                b_product *= primes[i];
                b_count++;
            }
        }

        if (a_count > 0 && b_count > 0 && a_product < b_product) {
            int diff = b_product - a_product;
            if (diff < best_diff) {
                best_diff = diff;
                best_a = a_product;
            }
        }
    }
    return best_a;
}

int main() {
    int n;
    cin >> n;
    int result = beautiful_partition(n);
    cout << result << endl;
    return 0;
}
